@@ -15,8 +15,9 @@ use Statistics::Basic::Mode;
 use Statistics::Basic::StdDev;
 use Statistics::Basic::Variance;
 use Statistics::Basic::Vector;
+use Statistics::Basic::ComputedVector;
 
-our $VERSION = "1.0";
+our $VERSION = "1.5";
 our $fmt = new Number::Format;
 
 $ENV{DEBUG} ||= 0;
@@ -26,7 +27,7 @@ use base 'Exporter';
 
 our @EXPORT      = ();
 our @EXPORT_OK   = (qw(
-    vector
+    vector computed
     mean average avg
     median
     mode
@@ -40,6 +41,8 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 1;
 
+sub computed { my $r = eval { ref($_[0]) ? Statistics::Basic::ComputedVector->new( $_[0] )   : Statistics::Basic::ComputedVector->new( [@_] );   }; croak $@ if $@; $r }
+
 sub vector   { my $r = eval { ref($_[0]) ? Statistics::Basic::Vector->new( $_[0] )   : Statistics::Basic::Vector->new( [@_] );   }; croak $@ if $@; $r }
 sub mean     { my $r = eval { ref($_[0]) ? Statistics::Basic::Mean->new( $_[0] )     : Statistics::Basic::Mean->new( [@_] );     }; croak $@ if $@; $r }
 sub median   { my $r = eval { ref($_[0]) ? Statistics::Basic::Median->new( $_[0] )   : Statistics::Basic::Median->new( [@_] );   }; croak $@ if $@; $r }
